SpecNameVersion

Struct SpecNameVersion 

#[repr(C)]
pub struct SpecNameVersion { pub printed_spec_version: String, pub spec_name: String, }
Metadata spec_name and spec_version.

There is a well-known Substrate type RuntimeVersion that describes the contents of Version constant in System pallet of the metadata in most chains. This RuntimeVersion has spec_version type set to u32. However, it is not necessarily the case that all chains in all versions will stick to u32, as the type of Version constant itself is described in the metadata.

Thus, metadata is printed into String, to accomodate reasonable types variation of the spec_version.

Fields

printed_spec_version: Stringspec_name: String