#[repr(C)]pub struct SpecNameVersion {
pub printed_spec_version: String,
pub spec_name: String,
}Expand description
Metadata spec_name and spec_version.
There is a well-known Substrate type
RuntimeVersion
that describes the contents of Version constant in System pallet of the
metadata in most chains. This RuntimeVersion has spec_version type set
to u32. However, it is not necessarily the case that all chains in all
versions will stick to u32, as the type of Version constant itself is
described in the metadata.
Thus, metadata is printed into String, to accomodate reasonable types
variation of the spec_version.
Fields
printed_spec_version: Stringspec_name: StringTrait Implementations
Sourceimpl Clone for SpecNameVersion
impl Clone for SpecNameVersion
Sourcefn clone(&self) -> SpecNameVersion
fn clone(&self) -> SpecNameVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpecNameVersion
impl Debug for SpecNameVersion
Sourceimpl Decode for SpecNameVersion
impl Decode for SpecNameVersion
Sourcefn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<SpecNameVersion, Error>where
__CodecInputEdqy: Input,
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<SpecNameVersion, Error>where
__CodecInputEdqy: Input,
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for SpecNameVersion
impl Encode for SpecNameVersion
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl PartialEq for SpecNameVersion
impl PartialEq for SpecNameVersion
impl EncodeLike for SpecNameVersion
impl Eq for SpecNameVersion
impl StructuralPartialEq for SpecNameVersion